Flask-WTF
=========

.. image:: https://img.shields.io/badge/flask-registered-green.svg?style=flat
   :target: https://github.com/pocoo/metaflask
   :alt: Meta Flask
.. image:: https://pypip.in/wheel/flask-wtf/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/Flask-WTF/
   :alt: Wheel Status
.. image:: https://pypip.in/version/flask-wtf/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/Flask-WTF/
   :alt: Latest Version
.. image:: https://travis-ci.org/lepture/flask-wtf.svg?branch=master
   :target: https://travis-ci.org/lepture/flask-wtf
   :alt: Travis CI Status
.. image:: https://coveralls.io/repos/lepture/flask-wtf/badge.svg?branch=master
   :target: https://coveralls.io/r/lepture/flask-wtf
   :alt: Coverage Status

Simple integration of Flask and WTForms, including CSRF, file upload
and Recaptcha integration.

For more information please refer to the online docs:

https://flask-wtf.readthedocs.org
